@@ -1,5 +1,5 @@
 /* Jody Bruchon's helpful code library header
- * Copyright (C) 2014-2025 by Jody Bruchon <jody@jodybruchon.com>
+ * Copyright (C) 2014-2026 by Jody Bruchon <jody@jodybruchon.com>
  * Licensed under The MIT License
  * Source code: https://codeberg.org/jbruchon/libjodycode
  */
@@ -23,8 +23,8 @@ extern "C" {
  * version information for compatibility. See README for more information. */
 #define LIBJODYCODE_API_VERSION       4
 #define LIBJODYCODE_API_FEATURE_LEVEL 5
-#define LIBJODYCODE_VER               "4.1.1"
-#define LIBJODYCODE_VERDATE           "2025-10-25"
+#define LIBJODYCODE_VER               "4.1.2"
+#define LIBJODYCODE_VERDATE           "2026-02-08"
 #ifdef UNICODE
  #define LIBJODYCODE_WINDOWS_UNICODE  1
 #else
@@ -157,6 +157,14 @@ struct JC_TIMESPEC {
 /*** stat ***/
 /* This is out of order because other things depend on it */
 
+/* Use st_?time macros for maximum cross-platform compatibility */
+
+#ifdef ON_MACOS
+ #define st_ctim st_ctimespec
+ #define st_mtim st_mtimespec
+ #define st_atim st_atimespec
+#endif /* ON_MACOS */
+
 #ifdef ON_WINDOWS
 struct JC_STAT {
 	uint64_t st_ino;
@@ -167,9 +175,13 @@ struct JC_STAT {
 	struct JC_TIMESPEC st_atim;
 	struct JC_TIMESPEC st_mtim;
 	struct JC_TIMESPEC st_ctim;
-	/* legacy st_*time should be avoided. Use st_*tim.tv_sec instead. */
 };
 
+/* legacy st_*time compatibility */
+ #define st_ctime st_ctim.tv_sec
+ #define st_mtime st_mtim.tv_sec
+ #define st_atime st_atim.tv_sec
+
 /* stat() macros for Windows "mode" flags (file attributes) */
  #define JC_S_IFMT FILE_ATTRIBUTE_ARCHIVE | FILE_ATTRIBUTE_READONLY | \
 	 FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM | \
